<?php
/**
 * Theme Customization
 *
 * @package kanagataTheme
 * @subpackage core_theme-option
 * @version 1.0.0
 * @since 1.0.0
 */

/**
 * Set Theme Customization API
 *
 * @param object $wp_customize customize object form wordpress system
 *
 * @since 1.0.0
 */
function kanagata_customize_register( $wp_customize )
{
	/*
	 * site title color
	 */
	$wp_customize->add_section(
		'site_title_color_section',
		array(
			'title'       => __( 'Site title color', 'kanagata' ),
			'priority'    => 25,
			'description' => __( 'Site title color applies when logo image don not sets.', 'kanagata' ),
		)
	);
	$wp_customize->add_setting(
		'site_title_color',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, 'site_title_color', array(
				'label'    => 'color',
				'section'  => 'site_title_color_section',
				'settings' => 'site_title_color',
			)
		)
	);
	/*
	 * logo image
	 */
	$wp_customize->add_section(
		'logo_image_section',
		array(
			'title'       => __( 'Logo image', 'kanagata' ),
			'priority'    => 30,
			'description' => __( 'Set site logo image.', 'kanagata' ),
		)
	);
	$wp_customize->add_setting(
		'logo_image',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'esc_url',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'logo_image',
			array(
				'label'    => __( 'Logo image', 'kanagata' ),
				'section'  => 'logo_image_section',
				'settings' => 'logo_image',
			)
		)
	);
	/*
	* Header right area customize
	 */
	$wp_customize->add_section(
		'header_section',
		array(
			'title'       => __( 'Header right area', 'kanagata' ),
			'priority'    => 35,
			'description' => __( 'This area display on header right area', 'kanagata' ),
		)
	);
	$wp_customize->add_setting(
		'header_item_text',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize, 'header_item_text', array(
				'label'    => __( 'Item text', 'kanagata' ),
				'section'  => 'header_section',
				'settings' => 'header_item_text',
				'priority' => 1,
			)
		)
	);
	$wp_customize->add_setting(
		'header_item_link',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'esc_url',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize, 'header_item_link', array(
				'label'    => __( 'Item link', 'kanagata' ),
				'section'  => 'header_section',
				'settings' => 'header_item_link',
				'priority' => 2,
			)
		)
	);
	$wp_customize->add_setting(
		'header_item_color',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, 'header_item_color', array(
				'label'    => __( 'Item color', 'kanagata' ),
				'section'  => 'header_section',
				'settings' => 'header_item_color',
				'priority' => 3,
			)
		)
	);
	$wp_customize->add_setting(
		'header_item_image',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'header_item_image',
			array(
				'label'    => __( 'Item image', 'kanagata' ),
				'section'  => 'header_section',
				'settings' => 'header_item_image',
				'priority' => 4,
			)
		)
	);
	/*
	 * footer
	 */
	$wp_customize->add_section(
		'footer_section',
		array(
			'title'    => __( 'Footer', 'kanagata' ),
			'priority' => 55,
		)
	);
	// footer background color
	$wp_customize->add_setting(
		'footer_background_color',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, 'footer_background_color', array(
				'label'    => __( 'footer background color', 'kanagata' ),
				'section'  => 'footer_section',
				'settings' => 'footer_background_color',
			)
		)
	);
	// copy right in footer
	$wp_customize->add_setting(
		'footer_copyright',
		array(
			'default'           => '',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize, 'footer_copyright', array(
				'label'    => __( 'copy right', 'kanagata' ),
				'section'  => 'footer_section',
				'settings' => 'footer_copyright',
			)
		)
	);
	// footer menu postion
	$wp_customize->add_setting(
		'footer_menu_align',
		array(
			'default'           => 'left',
			'type'              => 'theme_mod',
			'transport'         => 'refresh',
			'sanitize_callback' => 'kanagata_sanitize_align',
		)
	);
	$wp_customize->add_control(
		'footer_menu_align',
		array(
			'label'    => __( 'align of Footer Menu that can be set at Appearance > Menu', 'kanagata' ),
			'section'  => 'footer_section',
			'settings' => 'footer_menu_align',
			'type'     => 'radio',
			'choices'  => array(
				'left'   => __( 'Left', 'kanagata' ),
				'center' => __( 'Center', 'kanagata' ),
				'right'  => __( 'Right', 'kanagata' )
			),
		)
	);


}

add_action( 'customize_register', 'kanagata_customize_register' );