<?php
/**
 * Header settings
 *
 * @package kanagataTheme
 * @subpackage core
 * @version 1.0.0
 * @since 1.0.0
 */

/**
 * Load stylesheet
 *
 * @since 1.0
 */
function kanagata_load_stylesheets()
{
	wp_enqueue_style(
		'bootstrap',
		KANAGATA_ASSETS_CSS_URL . '/vendor/bootstrap/bootstrap.css',
		false,
		'3.3.4',
		'all'
	);
	wp_enqueue_style(
		'font-awesome',
		KANAGATA_ASSETS_CSS_URL . '/vendor/font-awesome/font-awesome.css',
		false,
		'4.3.0',
		'all'
	);
	wp_enqueue_style( 'kanagata-options', KANAGATA_ASSETS_CSS_URL . '/kanagata-options.css', false, '1.0', 'all' );
	wp_enqueue_style( 'style', get_stylesheet_uri(), false, '1.0', 'screen' );
}

add_action( 'wp_enqueue_scripts', 'kanagata_load_stylesheets' );

/**
 * Load script
 *
 * @since 1.0
 */
function kanagata_load_scripts()
{
	wp_enqueue_script( 'jquery' );
	$ua = getenv( 'HTTP_USER_AGENT' );
	if ( preg_match( '/MSIE 8/', $ua ) ) {
		wp_enqueue_script( 'html5', KANAGATA_ASSETS_JS_URL . '/vendor/html5shiv.js', array(), '3.7.3', false );
	}
	if ( is_singular() ) {
		wp_enqueue_script( "comment-reply" );
	}
	wp_enqueue_script(
		'kanagata_toggle_menu',
		KANAGATA_ASSETS_JS_URL . '/kanagata_toggle_menu.js',
		array( 'jquery' ),
		'1.0.0'
	);
	do_action( 'kanagata_load_additional_scripts' );
}

add_action( 'wp_enqueue_scripts', 'kanagata_load_scripts' );

/**
 * Add favicon
 *
 * callback of kanagata_head hook
 *
 * @since 1.0
 */
function kanagata_favicon()
{
	$favicon      = false;
	$favicon_path = false;
	if ( $favicon ) {
		echo apply_filters(
			'kanagata_do_favicon',
			"\n" . '<link rel="Shortcut Icon" href="' . esc_url( $favicon_path ) . '" type="image/x-icon" />'
		);
	}
}

add_action( 'wp_head', 'kanagata_favicon' );

/**
 * Add viewport in head
 *
 * @since 1.0
 */
function kanagata_viewport()
{
	$output = "\n" . '<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1" />';
	echo $output;
}

add_action( 'wp_head', 'kanagata_viewport' );

/**
 * Add generator meta tag in head
 *
 * @param string $generator from wordpress system
 * @return string generator meta generator string
 * 
 * @since 1.0
 */
function kanagata_generator( $generator )
{
	/** @var string $generator */
	$generator .= "\n" . '<meta name="generator" content="' . KANAGATA_NAME . ' ' . KANAGATA_VERSION . '" />';
	return $generator;
}

add_filter( 'the_generator', 'kanagata_generator' );
